/*!
  \file Draw_Polygon.c
  \author Mario Palomo <mpalomo@ihman.com>
  \author Jose M. de la Huerga Fernndez
  \author Pepe Gonzlez Mora
  \date 05-2002

  To provide a routine to draw 2D cubic bezier segments given two endpoints
  and two control points and bicubic surface patches given a 4x4 array of points.

*/

/*
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Foundation,
  Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

                                                       
void Draw_Bezier(SDL_Surface *super, 
		Sint16 Ax, Sint16 Ay, Sint16 Bx, Sint16 By, Sint16 Cx, Sint16 Cy, Sint16 Dx, Sint16 Dy,
		Uint32 color)
{
	float Incr = (float)0.1;
	float U = Incr;
	
	Sint16 OldX = Ax;
	Sint16 OldY = Ay;
	Sint16 PtX;
	Sint16 PtY;
	Sint16 i;
	float A;
	float B;
	float C;
	float D;
	
	for (i=0; i < 9; i++)
	{
		/* CALCULATE BEZIER CURVE FUNCTION COEFFICIENTSi */
		A = (1-U) * (1-U) * (1-U);
		B = 3 * U * (1-U) * (1-U);
		C = 3 * U * U * (1-U);
		D = U * U * U;
		
		/* FIND THE CURRENT PARAMETRIC POINT */
		PtX = (Sint16)(A*Ax + B*Bx + C*Cx + D*Dx);
		PtY = (Sint16)(A*Ay + B*By + C*Cy + D*Dy);
		
		/* DRAW THE LINE SEGMENT */
		Draw_Line(super, OldX, OldY, PtX, PtY, color);
		
		/* UPDATE "OLD" POINT */
		OldX = PtX;
		OldY = PtY;		
		
		U += Incr;
	}
	
	/* CONNECT THE LAST SEGMENT (NO NEED TO CALCULATE, MUST BE ENDPOINT) */
	Draw_Line(super, OldX, OldY, Dx, Dy, color);
}



