/*!
  \file Draw_Polygon.c
  \author Mario Palomo <mpalomo@ihman.com>
  \author Jose M. de la Huerga Fernndez
  \author Pepe Gonzlez Mora
  \date 05-2002

  Draws a Bilinerly interpolated mesh given four corner points. The mesh is set to
  16x16 patch subdivision. This was set to a power of two for a tremendous speed increase 
  with virtually no loss of presicion. This function should be modified so that it does
  not take all four points passes directly (slow funtion call).

*/

/*
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Foundation,
  Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/



void Draw_Bilinear(SDL_Surface *super, 
		  Sint16 Ax, Sint16 Ay, Sint16 Bx, Sint16 By, Sint16 Cx, Sint16 Cy, Sint16 Dx, Sint16 Dy, 
		  Uint32 color)
{
	/* CREATE MESH THROUGH INTERPOLATION */
	Sint16 AxtoBx = Bx-Ax;
	Sint16 AytoBy = By-Ay;
	Sint16 CxtoDx = Dx-Cx;
	Sint16 CytoDy = Dy-Cy;
	Sint16 AxtoCx = Cx-Ax;
	Sint16 AytoCy = Cy-Ay;
	Sint16 BxtoDx = Dx-Bx;
	Sint16 BytoDy = Dy-By;
	Sint16 T;

	for (T=0; T<=16; T++)
	{
	  /* INTERPOLATE POINTS */
	  Sint16 PtAx = Ax + ((AxtoBx*T)>>4);
	  Sint16 PtAy = Ay + ((AytoBy*T)>>4);
	  Sint16 PtBx = Cx + ((CxtoDx*T)>>4);
	  Sint16 PtBy = Cy + ((CytoDy*T)>>4);
	  			
	  Sint16 PtCx = Ax + ((AxtoCx*T)>>4);
	  Sint16 PtCy = Ay + ((AytoCy*T)>>4);
	  Sint16 PtDx = Bx + ((BxtoDx*T)>>4);
	  Sint16 PtDy = By + ((BytoDy*T)>>4);
					
	  /* DRAW INTERPOLATED LINES */
	  Draw_Line(super, PtAx, PtAy, PtBx, PtBy, color);
	  Draw_Line(super, PtCx, PtCy, PtDx, PtDy, color);
	}
}
